<?php

/**
 * @file
 * Default implementation of wsdata classes
 */



if (class_exists('WsConnector')) {

  class restclient_wsconnector extends WsConnector {

    public function getMethods() {
      return array(
        'single' => array(
          'create' => t('RESTful create method (POST)'),
          'read' => t('RESTful read method (GET)'),
          'update' => t('RESTful update method (PUT)'),
          'delete' => t('RESTful delete method (DELETE)'),
          'index' => t('RESTful index method (GET)'),
        ),
        'multiple' => array(
          'action' => t('RESTful action (POST)'),
        ),
      );
    }

    public function wscall( $type, $method, $arguments, $options) {
      $accepttype = "";
      if (isset($options['accept-type'])) {
        $accepttype = "." . $options['accept-type'];
      }
      switch ($type) {
        case 'create':
           $response = restclient_post( "$method$accepttype", array('endpoint' => $this->endpoint, 'body' => $arguments) + $options);
           if (restclient_response_code($response) != RESTCLIENT_RESPONSE_SUCCESS) {
             return FALSE;
           }
           else {
             return $response->data;
           }
        case 'read':
           $response = restclient_get( "$method$accepttype", array('endpoint' => $this->endpoint) + $options);
           // @todo add support for more 200 class response codes
           if (restclient_response_code($response) != RESTCLIENT_RESPONSE_SUCCESS) {
             return FALSE;
           }
           else {
             if (isset($response->expires)) {
               $this->expires = $response->expires;
             }
             return $response->data;
           }
        case 'update':
           $response = restclient_put( "$method$accepttype", array('endpoint' => $this->endpoint, 'body' => $arguments) + $options);
           if (restclient_response_code($response) != RESTCLIENT_RESPONSE_SUCCESS) {
             return FALSE;
           }
           else {
             return $response->data;
           }
        case 'delete':
           $response = restclient_delete( "$method$accepttype", array('endpoint' => $this->endpoint) + $options);
           if (restclient_response_code($response) != RESTCLIENT_RESPONSE_SUCCESS) {
             return FALSE;
           }
           else {
             return $response->data;
           }
        case 'index':
           $response = restclient_get( "$method$accepttype", array('endpoint' => $this->endpoint) + $options);
           // @todo add support for more 200 class response codes
           if (restclient_response_code($response) != RESTCLIENT_RESPONSE_SUCCESS) {
             return FALSE;
           }
           else {
             if (isset($response->expires)) {
               $this->expires = $response->expires;
             }
             return $response->data;
           }
	      default:
          if (drupal_substr($type,0,7) == 'action_') {
           $response = restclient_post( "$method$accepttype", array('endpoint' => $this->endpoint, 'body' => $arguments) + $options);
           if (restclient_response_code($response) != RESTCLIENT_RESPONSE_SUCCESS) {
             return FALSE;
           }
           else {
             return $response->data;
           }
         }
      }
    }

    /**
     * Custom impelementation of update
     *
     * With REST, the ID is part of the URL, so we don't need to included it
     * in the body.
     */ 
    public function update ($id, $method, $object, $options = array()) {
      $this->expires = 0;
      return $this->wscall('update', $method, $object, $options);
    }

  }
}

